# Training

::: flyvis.solver
    options:
      members:
        - MultiTaskSolver
        - Penalty
        - HyperParamScheduler
        - SchedulerFunction
      show_root_heading: false
      show_source: true
